# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .i_automated import IAutomated


class IAutomatedTableEditor(IAutomated):
    """ The IAutomatedTableEditor interface defines the API of automated
    editors that handle tables.
    """

    def simulate_append(self, id, delay, values):
        """ Simulate the user appending a row to the table.

        :param id:
            is the (possibly scoped) identifier of the widget.  This is
            normally used in exceptions.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param values:
            is the sequence of values to append.
        """

    def simulate_move(self, id, delay, from_row, from_column, to_row, to_column):
        """ Simulate the user moving a value within the table.

        :param id:
            is the (possibly scoped) identifier of the widget.  This is
            normally used in exceptions.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param from_row:
            is the initial row of the value being moved.
        :param from_column:
            is the initial column of the value being moved.
        :param to_row:
            is the final row of the value being moved.
        :param to_column:
            is the final column of the value being moved.
        """

    def simulate_remove(self, id, delay, row):
        """ Simulate the user removing a row from the table.

        :param id:
            is the (possibly scoped) identifier of the widget.  This is
            normally used in exceptions.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param row:
            is the row to remove.
        """

    def simulate_update(self, id, delay, value, row, column):
        """ Simulate the user updating a value in the table.

        :param id:
            is the (possibly scoped) identifier of the widget.  This is
            normally used in exceptions.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the new value.
        :param row:
            is the row of the value to update.
        :param column:
            is the column of the value to update.
        """
