# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ...model import implements, Model
from ...ui import (Form, ListEditor, MessageArea, Stretch, VBox, Wizard,
        IWizard, WizardPage)

from .. import IApplicationTemplate

from .python_class import PythonClass


@implements(IApplicationTemplate)
class ApplicationTemplate(Model):
    """ The ApplicationTemplate class is the default implementation of an
    application template.
    """

    # The wizard used to get the input from the user.
    wizard = Wizard(
            WizardPage(
                VBox(
                    Form(
                        'script_name',
                        'title_bar_text',
                        'interpreter'
                    ),
                    Stretch(),
                    MessageArea()
                ),
                title="Application Script",
                subtitle="Enter the details of the script to create."
            ),
            WizardPage(
                VBox(
                    ListEditor('plugins',
                            columns=['class_name', 'module_name'],
                            item_factory=lambda: PythonClass(
                                    class_name="NewPluginClass",
                                    module_name="new.module")),
                    Stretch(),
                    MessageArea()
                ),
                title="Plugins",
                subtitle="Enter the details of the application plugins.  " \
                        "Order is important as some plugins may depend on " \
                        "others."
            )
        )

    def populate(self, window_title, parent):
        """ Populate the application template with input from the user.

        :param window_title:
            is the window title to use.
        :param parent:
            is the parent view.
        :return:
            ``True`` if the template is populated.
        """

        ui = self.wizard(self, parent=parent, window_title=window_title)

        return IWizard(ui).execute()

    @IApplicationTemplate.plugins.default
    def plugins(self):
        """ Create the default list of plugins. """

        return [
                PythonClass(class_name='MainWindowShellPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='ModelManagerToolPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='DirtyToolPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='QuitToolPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='WhatsThisToolPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='FilesystemStoragePlugin',
                        module_name='dip.io.plugins')]
