# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import os

from ...model import implements, Model, observe
from ...shell import IModelSubscriber, ITool
from ...ui import Action, IAction, ActionCollection, Application

from .. import IBuilderProject

from .application_template import ApplicationTemplate


@implements(ITool, IModelSubscriber)
class CreateApplicationTool(Model):
    """ The CreateApplicationTool class implements a shell tool that creates an
    application script.
    """

    # The collection of actions.
    build_actions = ActionCollection('dip.builder.actions.create_application',
            '', text="Build", id='dip.builder.collections.build')

    # The create application script action.
    create_action = Action(text="Create application script...", enabled=False,
            id='dip.builder.actions.create_application')

    # The identifier of the tool.
    id = 'dip.builder.tools.create_application'

    @observe('published_model')
    def _published_model_changed(self, change):
        """ Invoked when the current model changes. """

        IAction(self.create_action).enabled = isinstance(change.new,
                IBuilderProject)

    @create_action.triggered
    def create_action(self):
        """ Invoked when the create application script action is triggered. """

        window_title = IAction(self.create_action).plain_text
        parent = self.shell

        # Get the application data from the user.
        template = ApplicationTemplate()

        if not template.populate(window_title, parent):
            return

        if os.path.exists(template.script_name):
            answer = Application.question(window_title,
                    "The file {0} already exists. Are you sure you "
                    "want to overwrite it?".format(template.script_name),
                    parent=parent)

            if answer != 'yes':
                return

        try:
            IBuilderProject(self.published_model).create_application(template)
        except:
            import traceback

            Application.warning(window_title,
                    "There was an error creating the application.",
                    parent=parent, detail=traceback.format_exc())
            return

        Application.information(window_title,
                "The file {0} was created successfuly.".format(
                        template.script_name),
                parent=parent)
