# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ...model import implements, Model
from ...plugins import IPlugin, IPluginManager
from ...ui import IDisplay

from .. import IDistributionManager


@implements(IPlugin, IDisplay)
class DistributionManagerPlugin(Model):
    """ The DistributionManagerPlugin class is the plugin definition for the
    configuration of the DistributionManager instance.
    """

    # The identifier of the plugin.
    id = 'dip.builder.DistributionManager'

    # The name of the plugin.
    name = "DIP builder distribution manager plugin"

    # The required plugins.
    requires = ['dip.builder.services.IDistributionManager']

    def configure(self, plugin_manager):
        """ Configure the plugin. """

        from ..distribution_manager import DistributionManager

        # Bind the IDistributionManager service to the DistributionsMaanger
        # singleton.
        IPluginManager(plugin_manager).bind_service(IDistributionManager,
                DistributionManager(), 'instance')
