# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .any import Any
from .instance import Instance
from .model import Model
from .str import Str


class AttributeChange(Model):
    """ The AttributeChange class contains the information that describes an
    observable change to a typed attribute.  An instance is passed to the
    observer defined using :func:`~dip.model.observe`.
    """

    # The model containing the changed attribute.
    model = Instance(Model)

    # The name of the changed attribute.
    name = Str()

    # The new value of the attribute.  If the type of the attribute is a
    # collection, e.g. a list, then the value is a collection of the items that
    # have been added.  Note that an item may appear in both in both ``new``
    # and ``old``.
    new = Any()

    # The old value of the attribute.  If the type of the attribute is a
    # collection, e.g. a list, then the value is a collection of the items that
    # have been removed.  Note that an item may appear in both in both ``new``
    # and ``old``.
    old = Any()
