# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Interface, List, Str


class IExtensionPoint(Interface):
    """ The IExtensionPoint interface defines the API of an
    :term:`extension point`.
    """

    # The list of contributions made.
    contributions = List()

    # The identifier of the extension point.
    id = Str()

    def bind(self, obj, name):
        """ Bind an attribute of an object to the extension point and update it
        with all contributions made so far.

        :param obj:
            is the object containing the attribute to bind to.
        :param name:
            is the name of the attribute to bind to.
        """

    def contribute(self, contribution):
        """ Contribute an object to all bound attributes.

        :param contribution:
            is the object to contribute.
        """
