# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Instance, Singleton

from .i_plugin_manager import IPluginManager


class PluginManager(Singleton):
    """ The PluginManager class is a singleton that provides access to a
    default :term:`plugin manager`.
    """

    # The plugin manager instance.
    instance = Instance(IPluginManager)

    @instance.default
    def instance(self):
        """ Invoked to return the plugin manager. """

        from .default_plugin_manager import PluginManager

        return PluginManager()

    @classmethod
    def add_plugin(cls, plugin):
        """ Add a plugin to the plugin manager.

        :param plugin:
            is the plugin.
        """

        ipluginmanager = IPluginManager(cls().instance)

        try:
            ipluginmanager._dip_io_plugin_configured
        except AttributeError:
            from ..io import IIoManager, IoManager

            # Rather than have a i/o manager plugin, now that we know we have a
            # plugin-aware application we just configure the core i/o manager.
            iiomanager = IIoManager(IoManager().instance)

            ipluginmanager.bind_extension_point('dip.io.codecs', iiomanager,
                    'codecs')
            ipluginmanager.bind_extension_point('dip.io.storage_factories',
                    iiomanager, 'storage_factories')
            ipluginmanager.bind_extension_point('dip.io.storage_policies',
                    iiomanager, 'storage_policies')

            ipluginmanager._dip_io_plugin_configured = True

        # Add the new plugin.
        ipluginmanager.plugins.append(plugin)
