# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..io import IStorageLocation
from ..model import Bool, Instance, List, Str
from ..ui import IView

from .i_dirty import IDirty


class IManagedModel(IDirty):
    """ The IManagedModel interface defines the API of a :term:`managed model`.
    """

    # The :term:`storage location` of the model.  It will be ``None`` if it is
    # not stored.  It will be updated automatically.
    location = Instance(IStorageLocation)

    # The identifier of the model's native format.
    native_format = Str()

    # This explains why the model is invalid.  It will be an empty string if the
    # model is valid.
    invalid_reason = Str()

    # The views that, when active, will cause the appropriate managed model
    # actions fo be enabled.
    views = List(IView)
