# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import implements, Instance, Model, observe, Str
from ..ui import IDisplay, IView

from .i_action_hints import IActionHints
from .i_area_hints import IAreaHints
from .i_shell import IShell
from .i_tool import ITool


@implements(ITool)
class SimpleViewTool(Model):
    """ The SimpleViewTool class is a base class for shell tools implemented
    as a single view and that allows for the use of an action that toggles the
    visibility of the view.
    """

    # The identifier to use for any action.
    action_id = Str()

    # The identifier of the area where the view should be placed.
    area = Str('dip.shell.areas.left')

    # The view implementation.
    view = Instance(IView)

    # The optional identifier of a collection of actions that any action will
    # be placed within.
    within = Str()

    @observe('shell')
    def _shell_changed(self, change):
        """ Invoked when the shell changes. """

        # Handle the trivial case.
        if self.view is None:
            return

        # Remove the view from any old shell.
        if change.old is not None:
            IShell(change.old).views.remove(self.view)

        # Add the view to any new shell.
        if change.new is not None:
            IAreaHints(self.view).area = self.area

            # Make sure the view implements IView.
            IView(self.view)
            IDisplay(self.view).name = self.name

            # Pass the action hints.
            action_hints = IActionHints(self.view)
            action_hints.id = self.action_id
            action_hints.within = self.within

            IShell(change.new).views.append(self.view)
