# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QPoint, Qt
from PyQt4.QtGui import QCheckBox
from PyQt4.QtTest import QTest

from ....automate import IAutomatedEditor
from ....model import adapt, Adapter
from ....ui import ICheckBox

from ..editor_widget_adapter import EditorWidgetAdapter


@adapt(QCheckBox, to=ICheckBox)
class QCheckBoxICheckBoxAdapter(EditorWidgetAdapter):
    """ An adapter to implement ICheckBox for a QCheckBox. """

    # The label policy.  The label is embedded but can be removed.
    label_policy = 'optional'

    def configure(self, properties):
        """ Configure the editor. """

        self.adaptee.stateChanged.connect(self._on_state_changed)

        super(QCheckBoxICheckBoxAdapter, self).configure(properties)

    def remove_label(self):
        """ Implement the 'optional' label policy. """

        self.adaptee.setText('')

    @ICheckBox.label.getter
    def label(self):
        """ Invoked to get the label. """

        return unicode(self.adaptee.text())

    @label.setter
    def label(self, value):
        """ Invoked to set the label. """

        self.adaptee.setText(value)

    @ICheckBox.value.getter
    def value(self):
        """ Invoked to get the editor's value. """

        return self.adaptee.checkState() != Qt.Unchecked

    @value.setter
    def value(self, value):
        """ Invoked to set the editor's value. """

        widget = self.adaptee

        # Save for the notifier.
        self.qt4_old_value = value

        blocked = widget.blockSignals(True)
        widget.setCheckState(Qt.Checked if value else Qt.Unchecked)
        widget.blockSignals(blocked)

    def _on_state_changed(self, state):
        """ Invoked when the state changes. """

        self.qt4_notify(state != Qt.Unchecked)


@adapt(QCheckBox, to=IAutomatedEditor)
class QCheckBoxIAutomatedEditorAdapter(Adapter):
    """ An adapter to implement IAutomatedEditor for the widget. """

    def simulate_set(self, id, delay, value):
        """ Simulate the user setting the editor value.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the value to set.
        """

        widget = self.adaptee
        checked = (widget.checkState() != Qt.Unchecked)

        if checked != value:
            QTest.mouseClick(widget, Qt.LeftButton, Qt.NoModifier, QPoint(),
                    delay)
