# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Instance, Singleton

from .i_toolkit import IToolkit


class Toolkit(Singleton):
    """ The Toolkit class is a singleton that provides access to a default
    :term:`toolkit`.
    """

    # The toolkit instance.
    instance = Instance(IToolkit)

    @instance.default
    def instance(self):
        """ Invoked to return the toolkit. """

        import sys
        import os

        # Get the name of the toolkit.
        toolkit_name = os.environ.get('DIP_TOOLKIT', 'qt4')

        # If the name is not a module path then assume it is a sub-package of
        # dip.toolkits.
        if '.' not in toolkit_name:
            toolkit_name = 'dip.toolkits.' + toolkit_name

        # Import the module and get the toolkit factory.
        __import__(toolkit_name)
        module = sys.modules[toolkit_name]
        toolkit_factory = getattr(module, 'Toolkit')

        # Create the toolkit.
        return toolkit_factory()
