# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Bool, Callable, Str, Trigger

from .i_object import IObject


class IAction(IObject):
    """ The IAction interface defines the API to be implemented by an
    :term:`action`.
    """

    # This is set if the action is checkable.
    checkable = Bool()

    # This is set if the action is checked.
    checked = Bool(False)

    # This is set if the action is enabled.
    enabled = Bool()

    # The plain text of the action.  This is the same as the text but with any
    # formatting hints (e.g. '&' or '...') removed.  It is typically used in
    # action specific dialog titles.
    plain_text = Str()

    # The shortcut.
    shortcut = Str()

    # The status tip.
    status_tip = Str()

    # The text of the action.
    text = Str()

    # The tool tip.
    tool_tip = Str()

    # This is set when the action is triggered.
    trigger = Trigger()

    # This is set if the widget is visible.
    visible = Bool()

    # The "What's This?" help.
    whats_this = Str()

    # This is called when the action is triggered.  It is passed the action as
    # its only argument.
    when_triggered = Callable()

    # The identifier of an optional collection of actions that this action will
    # be placed within.
    within = Str()
