# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Bool, Str, Tuple

from .i_editor import IEditor


class IOptionSelector(IEditor):
    """ The IOptionalSelector interface defines the API to be implemented by an
    editor that allows one of a number of options to be selected.
    """

    # This is set if ``None`` is allowed as a valid value.
    allow_none = Bool(True)

    # The optional option labels.  These are used to visualise the
    # corresponding options.
    labels = Tuple(Str())

    # The options.  If an option has no corresponding label then it will be
    # adapted to the :class:`~dip.ui.IDisplay` interface and its
    # :attr:`~dip.ui.IDisplay.name` used (which will default to its string
    # representation).
    options = Tuple()

    # This is set of the options should be sorted.
    sorted = Bool(False)
