# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Callable, Instance, Model, Str, TypeFactory


class ListColumn(Model):
    """ The ListColumn class represents the meta-data of the column of a list.
    """

    # The name of attribute that the column is bound to.  It will be empty if a
    # row is a list rather than a model.
    bind_to = Str()

    # The type of the column.  It should not be specified if the type can be
    # inferred from the attribute type.  If it is not specified and no type can
    # be inferred or the type is :class:`~dip.model.Any` then
    # :class:`~dip.model.Str` is used.
    column_type = Instance(TypeFactory)

    # The factory for the view created to edit a value in the column.  It will
    # default to the list editor's :attr:`~dip.ui.ListEdit.editor_factory`.
    editor_factory = Callable()

    # The label of the column.  It will default to a value derived from the
    # name of the attribute that the column is bound to.
    label = Str(None, allow_none=True)

    def __init__(self, bind_to=''):
        """ Initialise the column.

        :param bind_to:
            the name of the atribute that the column is bound to.  It should
            not be specified if a row is a list rather than a model.
        """

        super(ListColumn, self).__init__()

        # It's more natural to allow this as a positional argument.
        self.bind_to = bind_to
