# Copyright (c) 2012 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import Any, implements, List, Model
from dip.plugins import IPlugin, IPluginManager
from dip.plugins.default_plugin_manager import PluginManager


class Capture(Model):
    """ A utility class for binding to an extension point. """

    captured = List()


class TestPlugins(unittest.TestCase):
    """ This tests the default plugin manager's support for plugins. """

    def test_contribution_to(self):
        """ Test ContributionTo. """

        @implements(IPlugin)
        class TestPlugin(Model):
            id = 'test.plugin'
            injection = Any()

            def configure(self, plugin_manager):
                IPluginManager(plugin_manager).contribute('test.ep',
                        self.injection)

        capture = Capture()

        plugin_manager = PluginManager()

        plugin_manager.bind_extension_point('test.ep', capture, 'captured')

        injection = object()

        plugin = TestPlugin(enabled=False, injection=injection)

        plugin_manager.plugins.append(plugin)

        # Check the contribution doesn't happen until the plugin is enabled.
        self.assertEqual(len(capture.captured), 0)
        plugin.enabled = True
        self.assertEqual(len(capture.captured), 1)

        self.assertIs(capture.captured[0], injection)

    def test_contributions(self):
        """ Test a plugin's ability to create extension points dynamically. """

        @implements(IPlugin)
        class TestPlugin(Model):
            id = 'test.plugin'

            def configure(self, plugin_manager):
                IPluginManager(plugin_manager).contribute('test.odd', 1)
                IPluginManager(plugin_manager).contribute('test.odd', 3)

        plugin_manager = PluginManager()

        plugin_manager.plugins.append(TestPlugin())

        # Find the extension point.
        for ep in IPluginManager(plugin_manager).extension_points:
            if ep.id == 'test.odd':
                break
        else:
            ep = None

        self.assertIsNotNone(ep)
        self.assertListEqual(ep.contributions, [1, 3])


if __name__ == '__main__':
    unittest.main()
